@@ -30,8 +30,8 @@ def test_app_install_with_required_app(appcenter):
 
         app.install()
 
-        app.verify(joined=False)
-        app2.verify(joined=False)
+        app.verify()
+        app2.verify()
 
         lo = get_ldap_connection()
         print(lo.searchDn(filter=f'(&(cn={app_name[:5]}-*)(objectClass=univentionMemberServer)(!(aRecord=*))(!(macAddress=*)))', unique=True, required=True))
