@@ -1,21 +1,12 @@
 #!/usr/bin/python3
-#
-# -*- coding: utf-8 -*-
-#
 # SPDX-FileCopyrightText: 2023-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
-from __future__ import annotations
-
-from typing import TYPE_CHECKING
 
 from playwright.sync_api import Locator, Page, expect
 
 from univention.lib.i18n import Translation
-
-
-if TYPE_CHECKING:
-    from univention.testing.browser.lib import UMCBrowserTest
+from univention.testing.browser.lib import UMCBrowserTest
 
 
 _ = Translation('ucs-test-framework').translate
