@@ -3,10 +3,10 @@
 
 """Public interface for test resultes."""
 
-from __future__ import annotations
 
 import warnings
 from enum import Enum
+from typing import Self
 
 
 __all__ = ['Reason']
@@ -52,7 +52,7 @@ class Reason(Enum):
         return self.value[3]
 
     @classmethod
-    def lookup(cls, code: int) -> Reason:
+    def lookup(cls, code: int) -> Self:
         return next(obj for obj in cls.__members__.values() if int(obj) == code)
 
 
@@ -76,7 +76,7 @@ class _TestCodes:
     }
 
     def __getattribute__(self, item: str):
-        warnings.warn(f"deprecated use of TestCodes.{item}", DeprecationWarning, stacklevel=2)
+        warnings.warn("deprecated use of TestCodes.%s", item, DeprecationWarning, stacklevel=2)
         if item.startswith("REASON_"):
             return int(getattr(Reason, item[7:]))
         return object.__getattribute__(self, item)
